@@ -93,6 +93,7 @@
 #include "http_config.h"
 #include "http_conf_globals.h"
 #include "http_protocol.h"
+#include "http_request.h"
 #include "http_main.h"
 #include "http_core.h"
 #include "http_log.h"
@@ -551,6 +552,7 @@ void         ssl_init_SSLLibrary(void);
 void         ssl_init_GetCertAndKey(server_rec *, pool *, SSLSrvConfigRec *);
 STACK       *ssl_init_FindCAList(server_rec *, pool *, char *, char *);
 void         ssl_init_Child(server_rec *, pool *);
+void         ssl_init_ModuleKill(void *data);
 
 /*  Apache API hooks  */
 void         ssl_hook_AddModule(module *);
