@@ -459,7 +459,7 @@ void ssl_compat_variables(request_rec *r)
             * let vendor extensions provide a reasonable value first.
             */
             cpVal = NULL;
-            ap_hook_use("ssl::vendor::compat_variables_lookup", 
+            ap_hook_use("ap::mod_ssl::vendor::compat_variables_lookup", 
                         AP_HOOK_SIG3(ptr,ptr,ptr), 
                         AP_HOOK_DECLINE(NULL), 
                         &cpVal, r, cpOld);
