@@ -127,7 +127,8 @@ void ssl_config_global_create(void)
          * initialize per-module configuration
          */
         mc->nInitCount             = 0;
-        mc->pRSATmpKey             = NULL;
+        mc->pRSATmpKey512          = NULL;
+        mc->pRSATmpKey1024         = NULL;
         mc->nSessionCacheMode      = SSL_SCMODE_UNSET;
         mc->szSessionCacheDataFile = NULL;
         mc->nMutexMode             = SSL_MUTEXMODE_UNSET;
@@ -140,7 +141,7 @@ void ssl_config_global_create(void)
 
 #ifdef SSL_VENDOR
         mc->ctx = ap_ctx_new(pPool);
-        ap_hook_use("ssl::vendor::config_global_create", 
+        ap_hook_use("ap::mod_ssl::vendor::config_global_create", 
                 AP_HOOK_SIG2(void,ptr), AP_HOOK_MODE_ALL, mc);
 #endif
 
@@ -203,7 +204,7 @@ void *ssl_config_server_create(pool *p, server_rec *s)
 
 #ifdef SSL_VENDOR
     sc->ctx = ap_ctx_new(p);
-    ap_hook_use("ssl::vendor::config_server_create", 
+    ap_hook_use("ap::mod_ssl::vendor::config_server_create", 
                 AP_HOOK_SIG4(void,ptr,ptr,ptr), AP_HOOK_MODE_ALL,
                 p, s, sc);
 #endif
@@ -241,7 +242,7 @@ void *ssl_config_server_merge(pool *p, void *basev, void *addv)
 
 #ifdef SSL_VENDOR
     cfgMergeCtx(ctx);
-    ap_hook_use("ssl::vendor::config_server_merge", 
+    ap_hook_use("ap::mod_ssl::vendor::config_server_merge", 
                 AP_HOOK_SIG5(void,ptr,ptr,ptr,ptr), AP_HOOK_MODE_ALL,
                 p, base, add, new);
 #endif
@@ -272,7 +273,7 @@ void *ssl_config_perdir_create(pool *p, char *dir)
 
 #ifdef SSL_VENDOR
     dc->ctx = ap_ctx_new(p);
-    ap_hook_use("ssl::vendor::config_perdir_create", 
+    ap_hook_use("ap::mod_ssl::vendor::config_perdir_create", 
                 AP_HOOK_SIG4(void,ptr,ptr,ptr), AP_HOOK_MODE_ALL,
                 p, dir, dc);
 #endif
@@ -314,7 +315,7 @@ void *ssl_config_perdir_merge(pool *p, void *basev, void *addv)
 
 #ifdef SSL_VENDOR
     cfgMergeCtx(ctx);
-    ap_hook_use("ssl::vendor::config_perdir_merge", 
+    ap_hook_use("ap::mod_ssl::vendor::config_perdir_merge", 
                 AP_HOOK_SIG5(void,ptr,ptr,ptr,ptr), AP_HOOK_MODE_ALL,
                 p, base, add, new);
 #endif
@@ -597,7 +598,7 @@ const char *ssl_cmd_SSLSessionCache(
     }
 	else
 #ifdef SSL_VENDOR
-        if (!ap_hook_use("ssl::vendor::cmd_sslsessioncache", 
+        if (!ap_hook_use("ap::mod_ssl::vendor::cmd_sslsessioncache", 
              AP_HOOK_SIG4(void,ptr,ptr,ptr), AP_HOOK_MODE_ALL, 
              cmd, arg, mc))
 #endif
