@@ -127,6 +127,11 @@ void ssl_init_Module(server_rec *s, pool *p)
 
     mc->nInitCount++;
 
+    /*
+     * Let us cleanup on restarts and exists
+     */
+    ap_register_cleanup(p, s, ssl_init_ModuleKill, ap_null_cleanup);
+
     /*
      * Any init round fixes the global config
      */
@@ -587,3 +592,31 @@ void ssl_init_Child(server_rec *s, pool *p)
      return;
 }
 
+void ssl_init_ModuleKill(void *data)
+{
+    SSLSrvConfigRec *sc;
+    server_rec *s;
+
+    /*
+     * Free the non-pool allocated structures
+     * in the per-server configurations
+     */
+    s = (server_rec *)data;
+    for (; s != NULL; s = s->next) {
+        sc = mySrvConfig(s);
+        if (sc->px509Certificate != NULL) {
+            X509_free(sc->px509Certificate);
+            sc->px509Certificate = NULL;
+        }
+        if (sc->prsaKey != NULL) {
+            RSA_free(sc->prsaKey);
+            sc->prsaKey = NULL;
+        }
+        if (sc->pSSLCtx != NULL) {
+            SSL_CTX_free(sc->pSSLCtx);
+            sc->pSSLCtx = NULL;
+        }
+    }
+    return;
+}
+
