@@ -438,6 +438,7 @@ void ssl_hook_TimeoutConnection(int sig)
 void ssl_hook_CloseConnection(conn_rec *conn)
 {
     SSL *ssl;
+    char *cpType;
 
     ssl = ap_ctx_get(conn->client->ctx, "ssl");
     if (ssl == NULL)
@@ -475,8 +476,28 @@ void ssl_hook_CloseConnection(conn_rec *conn)
      * 4.x) don't send one, so we would hang.
      */
 
-    /* send close notify message */
-    SSL_set_shutdown(ssl, SSL_RECEIVED_SHUTDOWN);
+    /* 
+     * exchange close notify messages, but allow the user
+     * to force the type of handshake via SetEnvIf directive
+     */
+    if (ap_ctx_get(conn->client->ctx, "ssl::flag::unclean-shutdown") == (void *)1) {
+        /* perform no close notify handshake at all 
+           (violates the SSL/TLS standard!) */
+        SSL_set_shutdown(ssl, SSL_SENT_SHUTDOWN|SSL_RECEIVED_SHUTDOWN);
+        cpType = "unclean";
+    }
+    else if (ap_ctx_get(conn->client->ctx, "ssl::flag::accurate-shutdown") == (void *)1) {
+        /* send close notify and wait for clients close notify 
+           (standard compliant, but usually causes connection hangs) */
+        SSL_set_shutdown(ssl, 0);
+        cpType = "accurate";
+    }
+    else {
+        /* send close notify, but don't wait for clients close notify
+           (standard compliant and safe, so it's the DEFAULT!) */
+        SSL_set_shutdown(ssl, SSL_RECEIVED_SHUTDOWN);
+        cpType = "standard";
+    }
     SSL_smart_shutdown(ssl);
 
     /* deallocate the SSL connection */
@@ -485,8 +506,8 @@ void ssl_hook_CloseConnection(conn_rec *conn)
 
     /* and finally log the fact that we've closed the connection */
     ssl_log(conn->server, SSL_LOG_INFO, 
-            "Connection to child %d closed (server %s)",
-            conn->child_num, ssl_util_vhostid(conn->pool, conn->server));
+            "Connection to child %d closed with %s shutdown (server %s)",
+            conn->child_num, cpType, ssl_util_vhostid(conn->pool, conn->server));
     return;
 }
 
@@ -529,14 +550,31 @@ int ssl_hook_Translate(request_rec *r)
     if (ap_ctx_get(r->connection->client->ctx, "ssl") == NULL)
         return DECLINED;
 
-    ssl_log(r->server, SSL_LOG_INFO, 
-            "%s HTTPS request received for child %d (server %s)",
-            r->connection->keepalives <= 0 ? 
-                "Initial (No.1)" :
-                ap_psprintf(r->pool, "Subsequent (No.%d)", 
-                            r->connection->keepalives+1),
-            r->connection->child_num, 
-            ssl_util_vhostid(r->pool, r->server));
+    /*
+     * Log information about incoming HTTPS requests
+     */
+    if (ap_is_initial_req(r))
+        ssl_log(r->server, SSL_LOG_INFO, 
+                "%s HTTPS request received for child %d (server %s)",
+                r->connection->keepalives <= 0 ? 
+                    "Initial (No.1)" :
+                    ap_psprintf(r->pool, "Subsequent (No.%d)", 
+                                r->connection->keepalives+1),
+                r->connection->child_num, 
+                ssl_util_vhostid(r->pool, r->server));
+
+    /*
+     * Move SetEnvIf information from request_rec to conn_rec/BUFF
+     * to allow the close connection handler to use them.
+     */
+    if (ap_table_get(r->subprocess_env, "ssl-unclean-shutdown") != NULL)
+        ap_ctx_set(r->connection->client->ctx, "ssl::flag::unclean-shutdown", (void *)1);
+    else
+        ap_ctx_set(r->connection->client->ctx, "ssl::flag::unclean-shutdown", (void *)0);
+    if (ap_table_get(r->subprocess_env, "ssl-accurate-shutdown") != NULL)
+        ap_ctx_set(r->connection->client->ctx, "ssl::flag::accurate-shutdown", (void *)1);
+    else
+        ap_ctx_set(r->connection->client->ctx, "ssl::flag::accurate-shutdown", (void *)0);
 
     return DECLINED;
 }
