@@ -145,7 +145,7 @@ char *ssl_var_lookup(pool *p, server_rec *s, conn_rec *c, request_rec *r, char *
         else if (strcEQ(var, "THE_REQUEST"))
             result = r->the_request;
         else if (strcEQ(var, "REQUEST_METHOD"))
-            result = r->method;
+            result = (char *)(r->method);
         else if (strcEQ(var, "REQUEST_SCHEME"))
             result = ap_http_method(r);
         else if (strcEQ(var, "REQUEST_URI"))
