@@ -1,5 +1,3 @@
-#ifndef lint
-#endif
 #include <stdlib.h>
 #define YYBYACC 1
 #define YYMAJOR 1
@@ -9,12 +7,6 @@
 #define ssl_expr_yyclearin (ssl_expr_yychar=(YYEMPTY))
 #define ssl_expr_yyerrok (ssl_expr_yyerrflag=0)
 #define YYRECOVERING (ssl_expr_yyerrflag!=0)
-#if defined(c_plusplus) || defined(__cplusplus)
-#include <stdlib.h>
-#else
-extern char *getenv();
-extern void *realloc();
-#endif
 static int ssl_expr_yygrowstack();
 #define YYPREFIX "ssl_expr_yy"
 #include "mod_ssl.h"
